1.0.5
=====

* fixed Rlists

1.0.4
=====

* Minor bug fixes
* Typos
* More explicit error messages

1.0.3:
=======

* Will print a more meaningfull error if the database file could not be opened

1.0.1:
=======
* Added functions to free object registeries

1.0.0:
=======
The begining of a new era
